==> rnsf7.73.27a_src.zip: EXE/context/r7manifest.h <==
const char *r7manifest_utf8 =
"<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\r\n"
"<assembly xmlns=\"urn:schemas-microsoft-com:asm.v1\" manifestVersion=\"1.0\">\r\n"
"<assemblyIdentity\r\n"
"    version=\"1.0.0.0\"\r\n"
"    processorArchitecture=\"*\"\r\n"
"    name=\"INASOFT.Rnsf.Rnsf7\"\r\n"
"    type=\"win32\"\r\n"
"/>\r\n"
"<description>Rnsf7 - Customize Tool for Windows</description>\r\n"
"<dependency>\r\n"
"    <dependentAssembly>\r\n"
"        <assemblyIdentity\r\n"
"            type=\"win32\"\r\n"
"            name=\"Microsoft.Windows.Common-Controls\"\r\n"
"            version=\"6.0.0.0\"\r\n"
"            processorArchitecture=\"*\"\r\n"
"            publicKeyToken=\"6595b64144ccf1df\"\r\n"
"            language=\"*\"\r\n"
"        />\r\n"
"    </dependentAssembly>\r\n"
"</dependency>\r\n"
"\r\n"
"   <trustInfo xmlns=\"urn:schemas-microsoft-com:asm.v2\">\r\n"
"      <security>\r\n"
"        <requestedPrivileges>\r\n"
"          <requestedExecutionLevel level=\"%s\" uiAccess=\"false\" />\r\n"
"        </requestedPrivileges>\r\n"
"      </security>\r\n"
"   </trustInfo>\r\n"
"\r\n"
"  <compatibility xmlns=\"urn:schemas-microsoft-com:compatibility.v1\">\r\n"
"    <application>\r\n"
"      <!-- Windows 7 -->\r\n"
"      <supportedOS Id=\"{35138b9a-5d96-4fbd-8e2d-a2440225f93a}\"/>\r\n"
"      <!-- Windows 8 -->\r\n"
"      <supportedOS Id=\"{4a2f28e3-53b9-4441-ba9c-d69d4a4a6e38}\"/>\r\n"
"      <!-- Windows 8.1 -->\r\n"
"      <supportedOS Id=\"{1f676c76-80e1-4239-95bb-83d0f6d0da78}\"/>\r\n"
"    </application>\r\n"
"  </compatibility>\r\n"
"\r\n"
"</assembly>";

==> rnsf7.75.07_src.zip: EXE/context/r7manifest.h <==
const char *r7manifest_utf8 =
"<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\r\n"
"<assembly xmlns=\"urn:schemas-microsoft-com:asm.v1\" manifestVersion=\"1.0\">\r\n"
"<assemblyIdentity\r\n"
"    version=\"1.0.0.0\"\r\n"
"    processorArchitecture=\"*\"\r\n"
"    name=\"INASOFT.Rnsf.Rnsf7\"\r\n"
"    type=\"win32\"\r\n"
"/>\r\n"
"<description>Rnsf7 - Customize Tool for Windows</description>\r\n"
"<dependency>\r\n"
"    <dependentAssembly>\r\n"
"        <assemblyIdentity\r\n"
"            type=\"win32\"\r\n"
"            name=\"Microsoft.Windows.Common-Controls\"\r\n"
"            version=\"6.0.0.0\"\r\n"
"            processorArchitecture=\"*\"\r\n"
"            publicKeyToken=\"6595b64144ccf1df\"\r\n"
"            language=\"*\"\r\n"
"        />\r\n"
"    </dependentAssembly>\r\n"
"</dependency>\r\n"
"\r\n"
"   <trustInfo xmlns=\"urn:schemas-microsoft-com:asm.v2\">\r\n"
"      <security>\r\n"
"        <requestedPrivileges>\r\n"
"          <requestedExecutionLevel level=\"%s\" uiAccess=\"false\" />\r\n"
"        </requestedPrivileges>\r\n"
"      </security>\r\n"
"   </trustInfo>\r\n"
"\r\n"
"  <compatibility xmlns=\"urn:schemas-microsoft-com:compatibility.v1\">\r\n"
"    <application>\r\n"
"      <!-- Windows 7 -->\r\n"
"      <supportedOS Id=\"{35138b9a-5d96-4fbd-8e2d-a2440225f93a}\"/>\r\n"
"      <!-- Windows 8 -->\r\n"
"      <supportedOS Id=\"{4a2f28e3-53b9-4441-ba9c-d69d4a4a6e38}\"/>\r\n"
"      <!-- Windows 8.1 -->\r\n"
"      <supportedOS Id=\"{1f676c76-80e1-4239-95bb-83d0f6d0da78}\"/>\r\n"
"      <!-- Windows 10 -->\r\n"
"      <supportedOS Id=\"{8e0f7a12-bfb3-4fe8-b9a5-48fd50a15a9a}\"/>\r\n"
"    </application>\r\n"
"  </compatibility>\r\n"
"\r\n"
"</assembly>";
